==> haskell-network-ip-0.3-16-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-network-ip.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: network-ip
version: 0.3
id: network-ip-0.3-6gAllg3IhU42DlLUtnyT1f
key: network-ip-0.3-6gAllg3IhU42DlLUtnyT1f
license: BSD3
copyright: 2011-2016 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/network-ip
synopsis: Internet Protocol data structures
description:
    This package provides Internet Protocol data structures
category: Network
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
exposed: True
exposed-modules:
    Network.IP.Addr
abi: bbbe2fac11cea2f8cb039a304bb1c6ca
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/network-ip-0.3
library-dirs: /usr/lib/ghc-8.0.2/site-local/network-ip-0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.0.2/network-ip-0.3
hs-libraries: HSnetwork-ip-0.3-6gAllg3IhU42DlLUtnyT1f
depends:
    base-4.9.1.0 data-default-class-0.1.2.0-N42RtcTZUUAlapzICmPz4
    data-dword-0.3.1.1-1MG8mNTIyavEWsvOfESjf4
    data-endian-0.1.1-HoeJiLebjQqITdqdHm1S1Z
    data-serializer-0.3-JoyqVvKpQJs1Y9RiBrhPT0
    data-textual-0.3.0.2-CqziUZqxgMGAIsPMmf8JnS
    hashable-1.2.6.1-2nPqxcHq7mUGgurrYaLtXr
    parsers-0.12.5-6VUrmFpeF5oHKYq1qKXQZ
    text-printer-0.5-GUjVFi9dz4eFhZWiAdkvhT
    type-hint-0.1-AEo1fanTC1135pXDKdxmtL
haddock-interfaces: /usr/share/doc/haskell-network-ip/html/network-ip.haddock
haddock-html: /usr/share/doc/haskell-network-ip/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network-ip-0.3-19-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-network-ip.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: network-ip
version: 0.3
id: network-ip-0.3-7xkPGSmxkDF5lXILnDVOIT
key: network-ip-0.3-7xkPGSmxkDF5lXILnDVOIT
license: BSD3
copyright: 2011-2016 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/network-ip
synopsis: Internet Protocol data structures
description:
    This package provides Internet Protocol data structures
category: Network
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
exposed: True
exposed-modules:
    Network.IP.Addr
abi: 6273f6a9bdff5a9e3dd2e41e6d0e4c2d
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/network-ip-0.3
library-dirs: /usr/lib/ghc-8.0.2/site-local/network-ip-0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.0.2/network-ip-0.3
hs-libraries: HSnetwork-ip-0.3-7xkPGSmxkDF5lXILnDVOIT
depends:
    base-4.9.1.0 data-default-class-0.1.2.0-N42RtcTZUUAlapzICmPz4
    data-dword-0.3.1.1-1MG8mNTIyavEWsvOfESjf4
    data-endian-0.1.1-HoeJiLebjQqITdqdHm1S1Z
    data-serializer-0.3-8YGiN08hPv538Vggesnlf4
    data-textual-0.3.0.2-2Csu6Rxd02uGmBC1StUkLz
    hashable-1.2.6.1-2nPqxcHq7mUGgurrYaLtXr
    parsers-0.12.5-AXzq17gNTfCKs6hv5mWVL8
    text-printer-0.5-GUjVFi9dz4eFhZWiAdkvhT
    type-hint-0.1-AEo1fanTC1135pXDKdxmtL
haddock-interfaces: /usr/share/doc/haskell-network-ip/html/network-ip.haddock
haddock-html: /usr/share/doc/haskell-network-ip/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
